==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/calculel/merifs.f <==
      SUBROUTINE MERIFS(MODELE,NCHAR,LCHAR,MATE,CARA,EXITIM,TIME,MATEL,
     &                  NH)
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER NCHAR,NH
      REAL*8 TIME
      CHARACTER*8 MODELE,CARA,MATEL
      CHARACTER*(*) LCHAR(*),MATE
      LOGICAL EXITIM
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 11/09/2002   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
C     CALCUL DES MATRICES ELEMENTAIRES DE RIGIDITE MECA
C      OPTION 'RIGI_FLUI_STRU'.
C ----------------------------------------------------------------------
C IN  : MODELE : NOM DU MODELE  (PAS OBLIGATOIRE)
C IN  : NCHAR  : NOMBRE DE CHARGES
C IN  : LCHAR  : LISTE DES CHARGES
C IN  : MATE   : CARTE DE MATERIAU
C IN  : CARA   : CHAMP DE CARAC_ELEM
C IN  : MATEL  : NOM DU MATR_ELEM RESULTAT
C IN  : EXITIM : VRAI SI L'INSTANT EST DONNE
C IN  : TIME   : INSTANT DE CALCUL
C IN  : NH     : NUMERO D'HARMONIQUE DE FOURIER
C ----------------------------------------------------------------------
C     ----- DEBUT COMMUNS NORMALISES  JEVEUX  --------------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR
C     ------------------------------------------------------------------
      CHARACTER*8 K8B,LPAIN(11),LPAOUT(1)
      CHARACTER*16 OPTION
      CHARACTER*24 LIGRMO,LIGRCH,LCHIN(11),LCHOUT(10)
      CHARACTER*24 CHGEOM,CHCARA(15),CHTEMP,CHTREF,CHHARM

      CALL JEMARQ()
      OPTION = 'RIGI_FLUI_STRU'
      CALL MECHAM(OPTION,MODELE,NCHAR,LCHAR,CARA,NH,CHGEOM,CHCARA,
     &            CHHARM,ICODE)
      CALL MECHTE(MODELE,NCHAR,LCHAR,MATE,EXITIM,TIME,CHTREF,CHTEMP)

      CALL MEMARE('G',MATEL,MODELE,MATE,CARA,OPTION)
C     SI LA RIGIDITE EST CALCULEE SUR LE MODELE, ON ACTIVE LES S_STRUC:
      IF (ICODE.EQ.0 .OR. ICODE.EQ.2) THEN
        CALL JEVEUO(MATEL//'.REFE_RESU','E',IAREFE)
        ZK24(IAREFE-1+3) (1:3) = 'OUI'
      END IF

      CALL JEEXIN(MATEL//'.LISTE_RESU',IRET1)
      IF (IRET1.GT.0) CALL JEDETR(MATEL//'.LISTE_RESU')
      CALL WKVECT(MATEL//'.LISTE_RESU','G V K24',NCHAR+1,JLIRES)
      ILIRES = 0

      LPAOUT(1) = 'PMATUUR'
      LCHOUT(1) = MATEL//'.ME001'

      IF (ICODE.EQ.0) THEN
        LIGRMO = MODELE//'.MODELE'
        LPAIN(1) = 'PGEOMER'
        LCHIN(1) = CHGEOM
        LPAIN(2) = 'PMATERC'
        LCHIN(2) = MATE
        LPAIN(3) = 'PCAORIE'
        LCHIN(3) = CHCARA(1)
        LPAIN(4) = 'PCADISK'
        LCHIN(4) = CHCARA(2)
        LPAIN(5) = 'PCAGNPO'
        LCHIN(5) = CHCARA(6)
        LPAIN(6) = 'PCACOQU'
        LCHIN(6) = CHCARA(7)
        LPAIN(7) = 'PCASECT'
        LCHIN(7) = CHCARA(8)
        LPAIN(8) = 'PTEMPER'
        LCHIN(8) = CHTEMP
        LPAIN(9) = 'PCAARPO'
        LCHIN(9) = CHCARA(9)
        LPAIN(10) = 'PHARMON'
        LCHIN(10) = CHHARM
        LPAIN(11) = 'PABSCUR'
        LCHIN(11) = CHGEOM(1:8)//'.ABS_CURV'
        CALL CALCUL('S',OPTION,LIGRMO,11,LCHIN,LPAIN,1,LCHOUT,LPAOUT,
     &              'G')
        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ILIRES = ILIRES + 1
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        END IF
      END IF

      DO 10 ICHA = 1,NCHAR
        LIGRCH = LCHAR(ICHA) (1:8)//'.CHME.LIGRE'
        CALL JEEXIN(LCHAR(ICHA) (1:8)//'.CHME.LIGRE.LIEL',IRET)
        IF (IRET.LE.0) GO TO 10
        LCHIN(1) = LCHAR(ICHA) (1:8)//'.CHME.CMULT'
        CALL EXISD('CHAMP_GD',LCHAR(ICHA) (1:8)//'.CHME.CMULT',IRET)
        IF (IRET.LE.0) GO TO 10

        LPAIN(1) = 'PDDLMUR'
        ILIRES = ILIRES + 1
        CALL CODENT(ILIRES,'D0',LCHOUT(1) (12:14))
        OPTION = 'MECA_DDLM_R'
        CALL CALCUL('S',OPTION,LIGRCH,1,LCHIN,LPAIN,1,LCHOUT,LPAOUT,'G')
        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        ELSE
          ILIRES = ILIRES - 1
        END IF
   10 CONTINUE
      CALL JEDETC('V','&&MECHTE',1)

      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/calculel/merifs.f <==
      SUBROUTINE MERIFS(MODELE,NCHAR,LCHAR,MATE,CARA,EXITIM,TIME,MATEL,
     &                  NH)
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER NCHAR,NH
      REAL*8 TIME
      CHARACTER*8 MODELE,CARA,MATEL
      CHARACTER*(*) LCHAR(*),MATE
      LOGICAL EXITIM
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 28/01/2005   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
C     CALCUL DES MATRICES ELEMENTAIRES DE RIGIDITE MECA
C      OPTION 'RIGI_FLUI_STRU'.
C ----------------------------------------------------------------------
C IN  : MODELE : NOM DU MODELE  (PAS OBLIGATOIRE)
C IN  : NCHAR  : NOMBRE DE CHARGES
C IN  : LCHAR  : LISTE DES CHARGES
C IN  : MATE   : CARTE DE MATERIAU
C IN  : CARA   : CHAMP DE CARAC_ELEM
C IN  : MATEL  : NOM DU MATR_ELEM RESULTAT
C IN  : EXITIM : VRAI SI L'INSTANT EST DONNE
C IN  : TIME   : INSTANT DE CALCUL
C IN  : NH     : NUMERO D'HARMONIQUE DE FOURIER
C ----------------------------------------------------------------------
C     ----- DEBUT COMMUNS NORMALISES  JEVEUX  --------------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR
C     ------------------------------------------------------------------
      CHARACTER*8 K8B,LPAIN(11),LPAOUT(1)
      CHARACTER*16 OPTION
      CHARACTER*24 LIGRMO,LIGRCH,LCHIN(11),LCHOUT(10)
      CHARACTER*24 CHGEOM,CHCARA(15),CHTEMP,CHTREF,CHHARM

      CALL JEMARQ()
      OPTION = 'RIGI_FLUI_STRU'
      CALL MECHAM(OPTION,MODELE,0,' ',CARA,NH,CHGEOM,CHCARA,
     &            CHHARM,ICODE)
      CALL MECHTE(MODELE,NCHAR,LCHAR,MATE,EXITIM,TIME,CHTREF,CHTEMP)

      CALL MEMARE('G',MATEL,MODELE,MATE,CARA,OPTION)
C     SI LA RIGIDITE EST CALCULEE SUR LE MODELE, ON ACTIVE LES S_STRUC:
      IF (ICODE.EQ.0 .OR. ICODE.EQ.2) THEN
        CALL JEVEUO(MATEL//'.REFE_RESU','E',IAREFE)
        ZK24(IAREFE-1+3) (1:3) = 'OUI'
      END IF

      CALL JEEXIN(MATEL//'.LISTE_RESU',IRET1)
      IF (IRET1.GT.0) CALL JEDETR(MATEL//'.LISTE_RESU')
      CALL WKVECT(MATEL//'.LISTE_RESU','G V K24',NCHAR+1,JLIRES)
      ILIRES = 0

      LPAOUT(1) = 'PMATUUR'
      LCHOUT(1) = MATEL//'.ME001'

      IF (ICODE.EQ.0) THEN
        LIGRMO = MODELE//'.MODELE'
        LPAIN(1) = 'PGEOMER'
        LCHIN(1) = CHGEOM
        LPAIN(2) = 'PMATERC'
        LCHIN(2) = MATE
        LPAIN(3) = 'PCAORIE'
        LCHIN(3) = CHCARA(1)
        LPAIN(4) = 'PCADISK'
        LCHIN(4) = CHCARA(2)
        LPAIN(5) = 'PCAGNPO'
        LCHIN(5) = CHCARA(6)
        LPAIN(6) = 'PCACOQU'
        LCHIN(6) = CHCARA(7)
        LPAIN(7) = 'PCASECT'
        LCHIN(7) = CHCARA(8)
        LPAIN(8) = 'PTEMPER'
        LCHIN(8) = CHTEMP
        LPAIN(9) = 'PCAARPO'
        LCHIN(9) = CHCARA(9)
        LPAIN(10) = 'PHARMON'
        LCHIN(10) = CHHARM
        LPAIN(11) = 'PABSCUR'
        LCHIN(11) = CHGEOM(1:8)//'.ABS_CURV'
        CALL CALCUL('S',OPTION,LIGRMO,11,LCHIN,LPAIN,1,LCHOUT,LPAOUT,
     &              'G')
        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ILIRES = ILIRES + 1
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        END IF
      END IF

      DO 10 ICHA = 1,NCHAR
        LIGRCH = LCHAR(ICHA) (1:8)//'.CHME.LIGRE'
        CALL JEEXIN(LCHAR(ICHA) (1:8)//'.CHME.LIGRE.LIEL',IRET)
        IF (IRET.LE.0) GO TO 10
        LCHIN(1) = LCHAR(ICHA) (1:8)//'.CHME.CMULT'
        CALL EXISD('CHAMP_GD',LCHAR(ICHA) (1:8)//'.CHME.CMULT',IRET)
        IF (IRET.LE.0) GO TO 10

        LPAIN(1) = 'PDDLMUR'
        ILIRES = ILIRES + 1
        CALL CODENT(ILIRES,'D0',LCHOUT(1) (12:14))
        OPTION = 'MECA_DDLM_R'
        CALL CALCUL('S',OPTION,LIGRCH,1,LCHIN,LPAIN,1,LCHOUT,LPAOUT,'G')
        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        ELSE
          ILIRES = ILIRES - 1
        END IF
   10 CONTINUE
      CALL JEDETC('V','&&MECHTE',1)

      CALL JEDEMA()
      END
